@@ -22,7 +22,7 @@ class Publisher(object):
         )
 
     def publish(self, body, raise_exception=False, retry_connection=0, **kwargs):
-        LOGGER.info('Publishing message %s', body, **kwargs)
+        LOGGER.info('Publishing message %s, %s', body, kwargs)
 
         future = self.instance.publish(
             self.topic_name, json.dumps(body).encode('utf-8'), **kwargs)
